ToCigarOps

Trait ToCigarOps 

pub trait ToCigarOps {
    // Required method
    fn to_cigar_ops(&self) -> Result<CigarOps>;
}
Converts a format-specific CIGAR representation into the common CigarOps type.

Implemented for:

Required Methods

fn to_cigar_ops(&self) -> Result<CigarOps>

Parse and return the CIGAR as a CigarOps vector.

Returns an error if any operation character is unrecognised or a length field cannot be parsed as a usize.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToCigarOps for &str

Source

impl ToCigarOps for dyn SamCigar

Source

impl<'a> ToCigarOps for Cigar<'a>

Implementors